-- wTaskNote.lua: Sep 2010
-- Main LUA file, controls the minimap icon and the options dialog

-- Localization, works in conjunction with the wowace.com website
local L = LibStub("AceLocale-3.0"):GetLocale("wTaskNote")

-- Create a basic AceAddon object to base everything off of
-- See: http://www.wowace.com/addons/ace3/pages/getting-started/
-- We mixin the AceConsole bit so that our addon can have slash commands
wTaskNote = LibStub("AceAddon-3.0"):NewAddon("wTaskNote", "AceConsole-3.0")

-- Use LDBIcon to do the minimap icon (similar to how Omen does it)
-- http://forums.wowace.com/showthread.php?t=15728
local LDB = LibStub("LibDataBroker-1.1", true)
local LDBIcon = LDB and LibStub("LibDBIcon-1.0", true)

-----------------------------------------------------------------------------
-- DB defaults (see AceDB3)
-- Referencing things here is like: self.db.global.minimap.hide
-- Because the "db" object is a child of wTaskNote
local wTaskNoteDefaults = {
	global = {
		minimap = {
			hide = false,
			minimapPos = 250,
			radius = 80,
		},
	}
}

-----------------------------------------------------------------------------
-- Options table for AceConfig3
-- Works with the Ace3 libraries to setup and control the options menu
-- Right now, we're just doing a checkbox to show/hide the minimap button
local wTaskNoteOptions = {
	name = L["Options Title"],
	handler = wTaskNote,
	type = "group",
	args = {
		MinimapIcon = {
			type = "toggle",
			name = L["Options Show MiniMap Button"],
			desc = L["Options Show MiniMap Button Tooltip"],
			order = 1,
			get = function(info) return not wTaskNote.db.global.minimap.hide end,
			set = function(info, value)
				wTaskNote.db.global.minimap.hide = not value
				if value then LDBIcon:Show("wTaskNote") else LDBIcon:Hide("wTaskNote") end
			end,
			hidden = function() return not LDBIcon or IsAddOnLoaded("Broker2FuBar") or IsAddOnLoaded("FuBar") end,
			}
		}
	}

-----------------------------------------------------------------------------
-- OnInitialize(), Called by AceAddon when the addon is first loaded by the 
-- game client.  We'll be restoring saved settings here.  See also:
-- http://www.wowace.com/addons/ace3/pages/api/ace-addon-3-0/
function wTaskNote:OnInitialize()

	-- Initialize our persistent storage database (using AceDB3)
	self.db = LibStub("AceDB-3.0"):New("wTaskNoteDB", wTaskNoteDefaults)
	
	-- Options
	LibStub("AceConfig-3.0"):RegisterOptionsTable("wTaskNote", wTaskNoteOptions, nil)
	self.options = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("wTaskNote", L["wTaskNote"])
	
	-- Add console command of /wtn
	self:RegisterChatCommand("wtn", "ChatCommand")
	
	-- Minimap icon using LibDBIcon/LibDataBroker, similar to how Omen does it
	-- See: http://forums.wowace.com/showthread.php?t=15728
	-- For list of icons, see:
	-- http://www.wowwiki.com/WoWWiki:WoW_Icons/Icon_List/Images
	-- There are 17 different letter types (01-17): Interface\\Icons\\INV_Letter_##.blp
	-- There are 6 different note types (01-06): Interface\\Icons\\INV_Misc_Note_##.blp
	-- Note #3 has "1, 2, 3" on it, note #4 or #5 looks like a possible notes
	-- Also partial to letter #3, #6, #9, #11 or #14
	if LDB then
		self.dataObject = LDB:NewDataObject("wTaskNote", { 
			type = "launcher",
			icon = "Interface\\Icons\\INV_Letter_06.blp",
			OnClick = function (frame, button)
				if button == "RightButton" then
					self:ShowOptions()
				else
					self:ToggleNoteFrame()
				end
			end,
			OnTooltipShow = function(tooltip)
				tooltip:AddLine(L["MinimapTooltip Title"])
				tooltip:AddLine(L["MinimapTooltip LeftClick"])
				tooltip:AddLine(L["MinimapTooltip RightClick"])
			end,
		})
		if LDBIcon and not IsAddOnLoaded("Broker2FuBar") and not IsAddOnLoaded("FuBar") then
			LDBIcon:Register("wTaskNote", self.dataObject, self.db.global.minimap)
		end
	end
	
end

-----------------------------------------------------------------------------
-- OnEnable(), can be called multiple times per session by AceAddon if the 
-- user enables/disables your addon.  Gets called during the PLAYER_LOGIN event
function wTaskNote:OnEnable()
    
end

-----------------------------------------------------------------------------
-- OnDisable(), can be called multiple times per session by AceAddon if the 
-- user enables/disables your addon.
function wTaskNote:OnDisable()
    
end

-----------------------------------------------------------------------------
-- Shows the options panel
function wTaskNote:ShowOptions()
	InterfaceOptionsFrame_OpenToCategory(self.options)
end

-----------------------------------------------------------------------------
-- 
function wTaskNote:ChatCommand()
end